==> analitza-17.12.3.tgz: lib/cmake/Analitza5/Analitza5Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Analitza" for configuration "Release"
set_property(TARGET KF5::Analitza APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Analitza PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitza.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Analitza )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Analitza "${_IMPORT_PREFIX}/lib/libAnalitza.so.0.0" )

# Import target "KF5::AnalitzaPlot" for configuration "Release"
set_property(TARGET KF5::AnalitzaPlot APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaPlot PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaPlot.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaPlot )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaPlot "${_IMPORT_PREFIX}/lib/libAnalitzaPlot.so.0.0" )

# Import target "KF5::AnalitzaGui" for configuration "Release"
set_property(TARGET KF5::AnalitzaGui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaGui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaGui.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaGui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaGui "${_IMPORT_PREFIX}/lib/libAnalitzaGui.so.0.0" )

# Import target "KF5::AnalitzaWidgets" for configuration "Release"
set_property(TARGET KF5::AnalitzaWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Svg"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaWidgets.so.0.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaWidgets "${_IMPORT_PREFIX}/lib/libAnalitzaWidgets.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> analitza-18.12.0p0.tgz: lib/cmake/Analitza5/Analitza5Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Analitza" for configuration "Release"
set_property(TARGET KF5::Analitza APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Analitza PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitza.so.0.1"
  IMPORTED_SONAME_RELEASE "libAnalitza.so.0.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Analitza )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Analitza "${_IMPORT_PREFIX}/lib/libAnalitza.so.0.1" )

# Import target "KF5::AnalitzaPlot" for configuration "Release"
set_property(TARGET KF5::AnalitzaPlot APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaPlot PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaPlot.so.0.1"
  IMPORTED_SONAME_RELEASE "libAnalitzaPlot.so.0.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaPlot )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaPlot "${_IMPORT_PREFIX}/lib/libAnalitzaPlot.so.0.1" )

# Import target "KF5::AnalitzaGui" for configuration "Release"
set_property(TARGET KF5::AnalitzaGui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaGui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaGui.so.0.1"
  IMPORTED_SONAME_RELEASE "libAnalitzaGui.so.0.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaGui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaGui "${_IMPORT_PREFIX}/lib/libAnalitzaGui.so.0.1" )

# Import target "KF5::AnalitzaWidgets" for configuration "Release"
set_property(TARGET KF5::AnalitzaWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::AnalitzaWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt5::Svg"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libAnalitzaWidgets.so.0.1"
  IMPORTED_SONAME_RELEASE "libAnalitzaWidgets.so.0.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AnalitzaWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AnalitzaWidgets "${_IMPORT_PREFIX}/lib/libAnalitzaWidgets.so.0.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
